@@ -19,10 +19,6 @@ static __inline__ _syscall3(int, __syscall_mknod, const char *, path,
 
 int mknod(const char *path, mode_t mode, dev_t dev)
 {
-	/* We must convert the dev_t value to a __kernel_dev_t */
-	__kernel_dev_t k_dev;
-
-	k_dev = ((major(dev) & 0xff) << 8) | (minor(dev) & 0xff);
-	return __syscall_mknod(path, mode, k_dev);
+	return __syscall_mknod(path, mode, (__kernel_dev_t)dev);
 }
 libc_hidden_def(mknod)
