@@ -4,8 +4,9 @@
  * our private content, and not the kernel header, will win.
  *  -Erik
  */
-#ifndef __ASM_SH_POSIX_TYPES_H
+#if !defined __ASM_SH_POSIX_TYPES_H && !defined __ASM_SH_POSIX_TYPES_32_H
 #define __ASM_SH_POSIX_TYPES_H
+#define __ASM_SH_POSIX_TYPES_32_H
 
 typedef unsigned short	__kernel_dev_t;
 typedef unsigned long	__kernel_ino_t;
